compute_oviposit.RM_stochastic: Compute number of eggs laid from oviposition for each patch for stochastic RM model
Description
Compute number of eggs laid from oviposition for each patch for stochastic RM model
Usage
# S3 method for RM_stochastic
compute_oviposit(model)
Value
a vector of length l giving the total number of eggs laid by adult mosquitoes in each patch
Arguments
- model
an object from make_MicroMoB