dts_lines_X_SIS: Add lines for the density of infected individuals for the SIS...

View source: R/human-SIS.R

dts_lines_X_SISR Documentation

Add lines for the density of infected individuals for the SIS model

Description

Add lines for the density of infected individuals for the SIS model

Usage

dts_lines_X_SIS(XH, nStrata, clrs = c("darkblue", "darkred"), llty = 1)

Arguments

XH

a list with the outputs of parse_dts_out_X_SIS

nStrata

the number of population strata

clrs

a vector of colors

llty

an integer (or integers) to set the lty for plotting


dd-harp/MicroMoB documentation built on June 6, 2024, 4:43 p.m.