Change the daily maturation probability parameter molt for some times
and places. The parameter molt is stored internally as a matrix so that times
and places are used to modify a submatrix, therefore the new value molt should
either be a scalar value to update the entire submatrix or a matrix of places rows
and times columns.
set_molt_aqua_BH(model, molt, times, places)no return value
an object from make_MicroMoB
new daily maturation probability
vector of times to set the new values
vector of places to set the new values