Change the daily survival probability parameter surv for some times
and places. The parameter surv is stored internally as a matrix so that times
and places are used to modify a submatrix, therefore the new value surv should
either be a scalar value to update the entire submatrix or a matrix of places rows
and times columns.
set_surv_aqua_BH(model, surv, times, places)no return value
an object from make_MicroMoB
new daily survival probability
vector of times to set the new values
vector of places to set the new values