compute_emergents.trace_stochastic: Compute number of newly emerging adults from forcing term (stochastic)
Description
Draw a Poisson distributed number of emerging adults with mean parameter
from the column of the trace matrix for this day.
Usage
# S3 method for trace_stochastic
compute_emergents(model)
Value
a vector of length l giving the number of newly emerging adult in each patch
Arguments
- model
an object from make_MicroMoB